@@ -74,6 +74,8 @@ import com.openexchange.server.ServiceLookup;
 @SingletonService
 public class ClientManager extends DocumentConverterManager implements IDocumentConverter, Reloadable {
 
+    final private static String DC_CLIENT_PDF_EXTRACTOR_LOG_PREFIX = "DC client PDFExtractor";
+
     /**
      * @param services
      * @param config
@@ -106,7 +108,11 @@ public class ClientManager extends DocumentConverterManager implements IDocument
         m_remoteValidator = new RemoteValidator(m_clientConfig.REMOTEURL_DOCUMENTCONVERTER);
 
         try {
-            m_pdfExtractor = new PDFExtractor(this, m_clientConfig.PDFEXTRACTOR_EXECUTABLE_PATH);
+            m_pdfExtractor = new PDFExtractor(this, m_clientConfig.PDFEXTRACTOR_EXECUTABLE_PATH) {
+                public String getLogPrefix() {
+                    return DC_CLIENT_PDF_EXTRACTOR_LOG_PREFIX;
+                }
+            };
         } catch (IOException e) {
             logError("DC client PDFExtractor could not be initiaized correctly: " + m_clientConfig.PDFEXTRACTOR_EXECUTABLE_PATH);
         }
@@ -167,7 +173,7 @@ public class ClientManager extends DocumentConverterManager implements IDocument
      */
     @Override
     @Deprecated
-    public InputStream getConversionPage(String jobIdStr, int pageNumber, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties) {
+    public InputStream getConversionPage(String jobId, int pageNumber, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties) {
         DocumentConverterManager.logError("ManagedClientJob#getConversionPage is deprecated and must not be called anymore! Use #convert to PDF and PDFExtractor instead.");
         return null;
     }
@@ -177,7 +183,7 @@ public class ClientManager extends DocumentConverterManager implements IDocument
      */
     @Override
     @Deprecated
-    public void endPageConversion(String jobIdStr, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties) {
+    public void endPageConversion(String jobId, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties) {
         DocumentConverterManager.logError("ManagedClientJob#endPageConversion is deprecated and must not be called anymore! Use #convert to PDF and PDFExtractor instead.");
     }
 
@@ -233,7 +239,7 @@ public class ClientManager extends DocumentConverterManager implements IDocument
 
     // - PDFExtractor ----------------------------------------------------------
 
-    public PDFExtractor getPDFExtractor() {
+    @Nullable public PDFExtractor getPDFExtractor() {
         return m_pdfExtractor;
     }
 
@@ -253,5 +259,5 @@ public class ClientManager extends DocumentConverterManager implements IDocument
 
     final private AsyncExecutor m_asyncExecutor;
 
-    private PDFExtractor m_pdfExtractor;
+    private PDFExtractor m_pdfExtractor = null;
 }
