@@ -286,10 +286,6 @@ public class ManagedClientHashJob extends ManagedClientJob {
             }
         }
 
-        if (null != pseudoHashBuilder) {
-            pseudoHashBuilder.append('.').append(Properties.JOB_MAJOR_VERSION).append('.').append(Properties.JOB_MINOR_VERSION);
-        }
-
         return pseudoHashBuilder;
     }
 
