@@ -522,8 +522,8 @@ class ManagedClientJob {
                     DocumentConverterManager.logTrace(logTitle + " succeeded", jobProperties);
                 }
             } else if (DocumentConverterManager.isLogWarn()) {
-                // don't log warnings for cacheOnly jobs /
-                // don't log warnings for async jobs /
+                // don't log warnings for cacheOnly jobs
+                // don't log warnings for async jobs
                 // don't log warnings for remote cachehash jobs
                 // ------------------------------------------------------
                 // all above mentioned types of jobs may return without a
@@ -532,18 +532,11 @@ class ManagedClientJob {
                 // fallback conversion or the caller is not interested in the
                 // the current result of these 'try and ignore' conversions
                 if (!isCacheOnly && !isAsync && StringUtils.isEmpty(remoteCacheHash)) {
-                    final StringBuilder errorMessageBuilder = new StringBuilder("DC client received a remote conversion ");
-                    final JobError jobError = JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE));
-
-                    DocumentConverterManager.logWarn(errorMessageBuilder.append(
-                        (JobError.TIMEOUT == jobError) ? "timeout error" :
-                            (JobError.NO_CONTENT == jobError) ? "no content error" :
-                                (JobError.PASSWORD == jobError) ? "password error" :
-                                    (JobError.MAX_SOURCESIZE == jobError) ? "max source size error" :
-                                        (JobError.OUT_OF_MEMORY == jobError) ? "out of memory error" :
-                                            (JobError.ABORT == jobError) ? "abort error" :
-                                                (JobError.PDFTOOL == jobError) ? "PDFTool error" :
-                                                "general error").toString());
+                    DocumentConverterManager.logWarn(new StringBuilder(256).
+                        append("DC client remote conversion failed (").
+                        append("error=").append(JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE))).
+                        append(", filename=").append(DocumentConverterManager.getFilenameForLog((String) jobProperties.get(Properties.PROP_INFO_FILENAME))).
+                        append(')').toString());
                 }
             }
 
@@ -666,6 +659,11 @@ class ManagedClientJob {
                 paramBuilder.append("&cacheonly=").append(((Boolean) curParam).toString());
             }
 
+            // NoCache
+            if (null != (curParam = jobProperties.get(Properties.PROP_NO_CACHE))) {
+                paramBuilder.append("&nocache=").append(((Boolean) curParam).toString());
+            }
+
             // HideChanges
             if (null != (curParam = jobProperties.get(Properties.PROP_HIDE_CHANGES))) {
                 paramBuilder.append("&hidechanges=").append(((Boolean) curParam).toString());
