@@ -58,8 +58,8 @@ import java.util.concurrent.atomic.AtomicInteger;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import com.openexchange.documentconverter.DocumentConverterManager;
+import com.openexchange.documentconverter.DocumentConverterUtil;
 import com.openexchange.documentconverter.HttpHelper;
-import com.openexchange.documentconverter.HttpResponseProcessor;
 import com.openexchange.documentconverter.LogData;
 import com.openexchange.documentconverter.NonNull;
 
@@ -91,24 +91,39 @@ class RemoteValidator {
          */
         @Override
         public void run() {
+            final StringBuilder dcServerId = new StringBuilder(32);
             final AtomicInteger remoteApiVersion = new AtomicInteger(-1);
 
             // check remote connection API; may be checked repeatedly, if a valid remote URL is set
             if (null != m_remoteUrl) {
                 try {
-                    HttpHelper.get().executeGet(m_remoteUrl, new HttpResponseProcessor() {
-
-                        @Override
-                        public void processResponse(int responseCode, InputStream responseInputStream, String resultCookie) {
+                    HttpHelper.get().executeGet(
+                        m_remoteUrl,
+                        (int responseCode, InputStream responseInputStream, String resultCookie) -> {
                             try (final BufferedReader inputReader = new BufferedReader(new InputStreamReader(responseInputStream))) {
                                 for (String readLine = null; (readLine = inputReader.readLine()) != null;) {
                                     readLine = readLine.toLowerCase();
 
-                                    if (readLine.contains("open") && readLine.contains("xchange") && (readLine.contains("documentconverter"))) {
-                                        if (remoteApiVersion.get() < 0) {
+                                    // check, if we really have a DC server connection first
+                                    if (remoteApiVersion.get() < 0) {
+                                        // newer versions have the serverId set => try to extract this first
+                                        if (readLine.contains("id:")) {
+                                            final Matcher matcher = dcServerIDPattern.matcher(readLine);
+
+                                            if (matcher.find()) {
+                                                dcServerId.append(matcher.group(1));
+                                            }
+                                        }
+
+                                        // look for valid server id or old style 'open xchange documentconverter' string parts
+                                        if ((DocumentConverterUtil.DOCUMENTCONVERTER_SERVER_ID.equals(dcServerId.toString()) ||
+                                            (readLine.contains("open") && readLine.contains("xchange") && (readLine.contains("documentconverter"))))) {
+
                                             remoteApiVersion.set(1);
                                         }
-                                    } else if (readLine.contains("api:")) {
+                                    }
+
+                                    if (readLine.contains("api:")) {
                                         final Matcher matcher = apiVersionPattern.matcher(readLine);
 
                                         if (matcher.find()) {
@@ -119,8 +134,7 @@ class RemoteValidator {
                             } catch (@SuppressWarnings("unused") Exception e) {
                                 // #52867: no action intended here
                             }
-                        }
-                    });
+                        });
                 } catch (@SuppressWarnings("unused") Exception e) {
                     // #52867: no action intended here
                 }
@@ -130,7 +144,7 @@ class RemoteValidator {
                     final long curLogTime = System.currentTimeMillis();
 
                     if ((0 == m_lastLogTime) || ((curLogTime - m_lastLogTime) >= LOG_TIMEOUT)) {
-                        DocumentConverterManager.logError("DC remote connection could not be established => please check remote converter setup",
+                        DocumentConverterManager.logError("DC client remote connection could not be established => please check remote converter setup",
                             new LogData("remoteurl", m_remoteUrl.toString()),
                             new LogData("async_request", "true"));
                     }
@@ -138,7 +152,7 @@ class RemoteValidator {
                     m_lastLogTime = curLogTime;
                 } else {
                     // connection established
-                    DocumentConverterManager.logInfo("DC established remote connection",
+                    DocumentConverterManager.logInfo("DC client established remote connection",
                         new LogData("remoteurl", m_remoteUrl.toString()),
                         new LogData("async_request", "true"));
                 }
@@ -206,7 +220,7 @@ class RemoteValidator {
         m_remoteAPIVersion.set(-1);
 
         if (DocumentConverterManager.isLogError()) {
-            DocumentConverterManager.logError("DC lost remote connection:", new LogData("remoteurl", m_remoteUrl.toString()));
+            DocumentConverterManager.logError("DC client lost remote connection:", new LogData("remoteurl", m_remoteUrl.toString()));
         }
     }
 
@@ -229,6 +243,7 @@ class RemoteValidator {
     // - Static members --------------------------------------------------------
 
     protected static Pattern apiVersionPattern = Pattern.compile("api\\:\\s*v([0-9]+)");
+    protected static Pattern dcServerIDPattern = Pattern.compile("id\\:\\s*(([0-9a-f]+\\-){4}[0-9a-f]+)");
 
     // - Members ---------------------------------------------------------------
 
