@@ -55,7 +55,6 @@ import java.util.HashMap;
 import java.util.UUID;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.FilenameUtils;
-import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.StringUtils;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -82,7 +81,7 @@ import com.openexchange.file.storage.composition.IDBasedFileAccessFactory;
 import com.openexchange.file.storage.composition.crypto.CryptographicAwareIDBasedFileAccessFactory;
 import com.openexchange.file.storage.composition.crypto.CryptographyMode;
 import com.openexchange.groupware.attach.Attachments;
-import com.openexchange.groupware.ldap.User;
+import com.openexchange.java.Streams;
 import com.openexchange.mail.MailServletInterface;
 import com.openexchange.mail.compose.Attachment;
 import com.openexchange.mail.compose.CompositionSpaceService;
@@ -90,6 +89,7 @@ import com.openexchange.mail.compose.CompositionSpaces;
 import com.openexchange.mail.dataobjects.MailPart;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.session.ServerSession;
+import com.openexchange.user.User;
 
 /**
  * {@link DocumentConverterAction}
@@ -104,7 +104,15 @@ public abstract class DocumentConverterAction implements AJAXActionService {
     // The parameter list is used for the fast detection of ManagedFiles, based on
     // the set of all given attributes to create a unique identifier. The ManagedFile itself
     // is created for the speedup of chunked requests, using the same source again and again
-    final static private String[] idParamArray = { "uid", "id", "folder_id", "version", "revtag", "source", "attached", "module", "cryptoAuth", "attachmentId" };
+    final private static String[] idParamArray = { "uid", "id", "folder_id", "version", "revtag", "source", "attached", "module", "cryptoAuth", "attachmentId" };
+
+    final protected static String FORMAT_JSON = "json";
+
+    final protected static String FORMAT_FILE = "file";
+
+    final protected static String JSON_KEY_ERRORCODE = "errorCode";
+
+    final protected static String JSON_KEY_ERRORTEXT = "cause";
 
     /**
      * Initializes a new {@link DocumentConverterAction}.
@@ -126,9 +134,13 @@ public abstract class DocumentConverterAction implements AJAXActionService {
      * @param jobError
      * @return
      */
-    protected File getRequestSourceFile(@NonNull final AJAXRequestData request, @NonNull final ServerSession session, @NonNull final MutableWrapper<JobError> jobError) {
-        final String documentId = getDocumentId(request);
+    protected File getRequestSourceFile(
+        @NonNull final AJAXRequestData request,
+        @NonNull final ServerSession session,
+        @NonNull final MutableWrapper<Boolean> documentDecrypted,
+        @NonNull final MutableWrapper<JobError> jobError) {
 
+        final String documentId = getDocumentId(request);
         File ret = null;
 
         try {
@@ -163,6 +175,7 @@ public abstract class DocumentConverterAction implements AJAXActionService {
                             }
 
                             mailServletInterface = MailServletInterface.getInstanceWithDecryptionSupport(session, authentication);
+                            documentDecrypted.set(Boolean.TRUE);
                         } else {
                             mailServletInterface = MailServletInterface.getInstance(session);
                         }
@@ -213,6 +226,8 @@ public abstract class DocumentConverterAction implements AJAXActionService {
 
                                     fileAccess = encryptionAwareFileAccessFactory.createAccess(fileAccess, cryptMode, session,
                                         encryptionAuthenticationFactory.createAuthenticationFrom(request.optHttpServletRequest()));
+
+                                    documentDecrypted.set(Boolean.TRUE);
                                 } else {
                                     // file is encrypted, but we can't decrypt...
                                     fileAccess = null;
@@ -221,7 +236,7 @@ public abstract class DocumentConverterAction implements AJAXActionService {
                                 fileAccess = null;
                             }
 
-                            // set output paramter jobError to JobError.PASSWORD in
+                            // set output paramater jobError to JobError.PASSWORD in
                             // case we got no valid fileAccess for given Guard parameters
                             if (null == fileAccess) {
                                 jobError.set(JobError.PASSWORD);
@@ -251,7 +266,8 @@ public abstract class DocumentConverterAction implements AJAXActionService {
                 } catch (final Exception e) {
                     DocumentConverterManager.logExcp(e);
                 } finally {
-                    IOUtils.closeQuietly(documentStm);
+                    Streams.close(documentStm);
+
                     if (mailServletInterface != null) {
                         mailServletInterface.close();
                     }
@@ -261,6 +277,12 @@ public abstract class DocumentConverterAction implements AJAXActionService {
             m_fileIdManager.unlock(documentId);
         }
 
+        // set output parameter for decrypted document to
+        // FALSE if we have no document to return at all
+        if (null == ret) {
+            documentDecrypted.set(Boolean.FALSE);
+        }
+
         return ret;
     }
 
@@ -271,8 +293,13 @@ public abstract class DocumentConverterAction implements AJAXActionService {
      * @param resultJobError
      * @return
      */
-    protected File getPDFFile(@NonNull AJAXRequestData request, @NonNull ServerSession session, boolean isAsync,
-        final MutableWrapper<String> resultJobId, final MutableWrapper<JobError> resultJobError) {
+    protected File getPDFFile(
+        @NonNull final AJAXRequestData request,
+        @NonNull final ServerSession session,
+        final boolean isAsync,
+        @NonNull final MutableWrapper<Boolean> documentDecrypted,
+        @NonNull final MutableWrapper<String> resultJobId,
+        @NonNull final MutableWrapper<JobError> resultJobError) {
 
         final IDocumentConverter docConverter = m_services.getService(IDocumentConverter.class);
         File resultFile = null;
@@ -282,13 +309,15 @@ public abstract class DocumentConverterAction implements AJAXActionService {
         if (null != docConverter) {
             final String locale = getPreferredLanguage(session);
 
-            resultJobId.set(getDocumentId(request, "pdf", locale));
+            if (null == resultJobId.get()) {
+                resultJobId.set(getDocumentId(request, "pdf", locale));
+            }
 
             try {
                 m_fileIdManager.lock(resultJobId.get());
 
                 if (null == (resultFile = m_fileIdManager.getDataFile(resultJobId.get()))) {
-                    final File sourceFile = getRequestSourceFile(request, session, resultJobError);
+                    final File sourceFile = getRequestSourceFile(request, session, documentDecrypted, resultJobError);
 
                     if(null != sourceFile) {
                         final String fileName = request.getParameter("filename");
@@ -300,32 +329,46 @@ public abstract class DocumentConverterAction implements AJAXActionService {
                                 resultJobError.set(JobError.NONE);
                             }
                         } else {
-                            // convert to PDF
-                            final HashMap<String, Object> jobProperties = new HashMap<>(12);
-                            final HashMap<String, Object> resultProperties = new HashMap<>(8);
-
-                            jobProperties.put(Properties.PROP_INPUT_FILE, sourceFile);
-                            jobProperties.put(Properties.PROP_PRIORITY, JobPriority.fromString(request.getParameter("priority")));
-                            jobProperties.put(Properties.PROP_LOCALE, locale);
-
-                            if (null != fileName) {
-                                jobProperties.put(Properties.PROP_INFO_FILENAME, fileName);
-                            }
-
-                            if (isAsync) {
-                                jobProperties.put(Properties.PROP_ASYNC, Boolean.TRUE);
-                                jobProperties.put(Properties.PROP_PRIORITY, JobPriority.BACKGROUND);
+                            // convert to PDF via DocumentConverter
+                            if (isAsync && documentDecrypted.get().booleanValue()) {
+                                // we don't trigger any async conversion in case
+                                // of a decrypted document and leave ASAP since
+                                // we don't want to cache decrypted document
+                                // conversion results for security reasons
+                                resultJobError.set(JobError.NONE);
                             } else {
-                                // this is a user request in synchronous case
-                                jobProperties.put(Properties.PROP_USER_REQUEST, Boolean.TRUE);
-                            }
+                                final HashMap<String, Object> jobProperties = new HashMap<>(12);
+                                final HashMap<String, Object> resultProperties = new HashMap<>(8);
 
-                            try (InputStream pdfResultStm = docConverter.convert("pdf", jobProperties, resultProperties)) {
-                                if (null != pdfResultStm) {
-                                    resultFile = m_fileIdManager.setDataInputStream(resultJobId.get(), pdfResultStm);
-                                    resultJobError.set(JobError.NONE);
+                                jobProperties.put(Properties.PROP_INPUT_FILE, sourceFile);
+                                jobProperties.put(Properties.PROP_PRIORITY, JobPriority.fromString(request.getParameter("priority")));
+                                jobProperties.put(Properties.PROP_LOCALE, locale);
+
+                                if (null != fileName) {
+                                    jobProperties.put(Properties.PROP_INFO_FILENAME, fileName);
+                                }
+
+                                if (isAsync) {
+                                    jobProperties.put(Properties.PROP_ASYNC, Boolean.TRUE);
+                                    jobProperties.put(Properties.PROP_PRIORITY, JobPriority.BACKGROUND);
                                 } else {
-                                    resultJobError.set(isAsync ? JobError.NONE : JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE)));
+                                    // this is a user request in synchronous case
+                                    jobProperties.put(Properties.PROP_USER_REQUEST, Boolean.TRUE);
+                                }
+
+                                if (documentDecrypted.get().booleanValue()) {
+                                    // set 'NO_CACHE=true' property for decrypted documents since we don't
+                                    // want to cache decrypted document conversion results for security reasons
+                                    jobProperties.put(Properties.PROP_NO_CACHE, Boolean.TRUE);
+                                }
+
+                                try (InputStream pdfResultStm = docConverter.convert("pdf", jobProperties, resultProperties)) {
+                                    if (null != pdfResultStm) {
+                                        resultFile = m_fileIdManager.setDataInputStream(resultJobId.get(), pdfResultStm);
+                                        resultJobError.set(JobError.NONE);
+                                    } else {
+                                        resultJobError.set(isAsync ? JobError.NONE : JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE)));
+                                    }
                                 }
                             }
                         }
@@ -355,81 +398,21 @@ public abstract class DocumentConverterAction implements AJAXActionService {
         AJAXRequestResult ret = null;
 
         if ((jobError == JobError.NONE) && (null != fileHolder)) {
-            request.setFormat("file");
-            ret = new AJAXRequestResult(fileHolder, "file");
+            request.setFormat(FORMAT_FILE);
+            ret = new AJAXRequestResult(fileHolder, FORMAT_FILE);
         } else {
             final JSONObject jsonResult = (null != jsonObject) ? jsonObject : new JSONObject();
 
             try {
-                String errorCause = null;
-
-                switch (jobError) {
-                    case NONE: {
-                        break;
-                    }
-
-                    case TIMEOUT: {
-                        errorCause = "timeout";
-                        break;
-                    }
-
-                    case PASSWORD: {
-                        errorCause = "passwordProtected";
-                        break;
-                    }
-
-                    case NO_CONTENT: {
-                        errorCause = "noContent";
-                        break;
-                    }
-
-                    case MAX_SOURCESIZE: {
-                        errorCause = "maxSourceSizeExceeded";
-                        jsonResult.put("MaxSourceSizeMB", "" + (m_clientConfig.MAX_DOCUMENT_SOURCEFILESIZE / 1024) / 1024);
-                        break;
-                    }
-
-                    case DISPOSED: {
-                        errorCause = "engineDisposed";
-                        break;
-                    }
-
-                    case UNSUPPORTED: {
-                        errorCause = "unsupportedType";
-                        break;
-                    }
-
-                    case OUT_OF_MEMORY: {
-                        errorCause = "outOfMemory";
-                        break;
-                    }
-
-                    case ABORT: {
-                        errorCause = "abort";
-                        break;
-                    }
-
-                    case PDFTOOL: {
-                        errorCause = "pdfTool";
-                        break;
-                    }
-
-                    case GENERAL:
-                    default: {
-                        errorCause = "filterError";
-                        break;
-                    }
+                if ((null != jobError) && (jobError != JobError.NONE) && !jsonResult.has(JSON_KEY_ERRORTEXT)) {
+                    jsonResult.put(JSON_KEY_ERRORTEXT,  jobError.errorText());
                 }
-
-                if (null != errorCause) {
-                    jsonResult.put("cause", errorCause);
-                }
-            } catch (final JSONException e) {
+            } catch (JSONException e) {
                 DocumentConverterManager.logExcp(e);
             }
 
-            request.setFormat("json");
-            ret = new AJAXRequestResult(jsonResult, "json");
+            request.setFormat(FORMAT_JSON);
+            ret = new AJAXRequestResult(jsonResult, FORMAT_JSON);
         }
 
         return ret;
