@@ -64,13 +64,7 @@ import java.util.zip.ZipEntry;
 import java.util.zip.ZipInputStream;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.FilenameUtils;
-import org.apache.poi.hpsf.PropertySet;
-import org.apache.poi.hpsf.SummaryInformation;
-import org.apache.poi.poifs.filesystem.DirectoryEntry;
-import org.apache.poi.poifs.filesystem.DocumentEntry;
-import org.apache.poi.poifs.filesystem.DocumentInputStream;
-import org.apache.poi.poifs.filesystem.POIFSFileSystem;
-import org.apache.poi.util.IOUtils;
+import org.apache.commons.io.IOUtils;
 import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.conversion.Data;
 import com.openexchange.conversion.DataProperties;
@@ -83,7 +77,6 @@ import com.openexchange.documentconverter.Properties;
 import com.openexchange.documentconverter.client.impl.ClientManager;
 import com.openexchange.documentconverter.client.preview.PreviewResult.PreviewType;
 import com.openexchange.exception.OXException;
-import com.openexchange.groupware.ldap.User;
 import com.openexchange.imagetransformation.ImageTransformationService;
 import com.openexchange.imagetransformation.ScaleType;
 import com.openexchange.preview.PreviewDocument;
@@ -95,6 +88,7 @@ import com.openexchange.preview.RemoteInternalPreviewService;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.session.Session;
 import com.openexchange.tools.session.ServerSession;
+import com.openexchange.user.User;
 
 /**
  * {@link DocumentConverterPreviewService}
@@ -601,11 +595,6 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
 
         if (fastPreviewType != null) {
             switch (fastPreviewType) {
-            case COMPOUND_BINARY: {
-                fastPreviewResult = getCompoundBinaryPreview(inputFile);
-                break;
-            }
-
             case OOXML: {
                 final byte[] thumbnailBuffer = getZipThumbnailBuffer(inputFile, "docProps/thumbnail.jpeg");
 
@@ -636,73 +625,13 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
         return fastPreviewResult;
     }
 
-    /**
-     * @param inputBuffer
-     * @return
-     */
-    private static PreviewResult getCompoundBinaryPreview(@NonNull File inputFile) throws OXException {
-        POIFSFileSystem poifs = null;
-        PreviewResult previewResult = null;
-        InputStream inputStm = null;
-
-        try {
-            inputStm = new BufferedInputStream(FileUtils.openInputStream(inputFile));
-
-            try {
-                poifs = new POIFSFileSystem(inputStm);
-            } catch (@SuppressWarnings("unused") Exception e) {
-                // Fix for bug #32118:
-                // It is valid to suppress error output here, since
-                // we can't ensure that the header is always correctly
-                // formatted, so that this is considered to be a
-                // try and error call; a preview will still be created via
-                // standard conversion methods in error cases afterwards
-            }
-
-            if (null != poifs) {
-                try {
-                    final DirectoryEntry dir = poifs.getRoot();
-                    final DocumentEntry dsiEntry = (DocumentEntry) dir.getEntry(SummaryInformation.DEFAULT_STREAM_NAME);
-
-                    if (null != dsiEntry) {
-                        try (final DocumentInputStream documentInputStm = new DocumentInputStream(dsiEntry)) {
-                            final byte[] thumbnail = (new SummaryInformation(new PropertySet(documentInputStm))).getThumbnail();
-
-                            if ((null != thumbnail) && (thumbnail.length > 20) && (3 == thumbnail[8])) {
-                                try (final InputStream thumbnailInputStm = new ByteArrayInputStream(thumbnail, 20, thumbnail.length - 20)) {
-                                    final byte[] resultThumbnail = IOUtils.toByteArray(thumbnailInputStm);
-
-                                    if (null != resultThumbnail) {
-                                        previewResult = new PreviewResult("image/wmf", resultThumbnail);
-                                    }
-                                }
-                            }
-                        }
-                    }
-                } catch (@SuppressWarnings("unused") Exception e) {
-                    // #42224
-                    // it's not critical to silently step over here,
-                    // since we always have a fallback path for thumbnail generation
-                }
-            }
-        } catch (IOException e) {
-            handleExcp(e);
-        } finally {
-            IOUtils.closeQuietly(inputStm);
-        }
-
-        return previewResult;
-    }
-
     /**
      * @param e
      * @throws OXException
      */
     final protected static void handleExcp(Exception e) throws OXException {
         if (null != e) {
-            if (e instanceof org.apache.poi.poifs.filesystem.OfficeXmlFileException) {
-                DocumentConverterManager.logInfo("DC OfficePreviewService document ambiguity: cannot read binary document format with XML extension.");
-            } else if (e instanceof IOException) {
+            if (e instanceof IOException) {
                 throw PreviewExceptionCodes.IO_ERROR.create(e, e.getMessage());
             } else if (e instanceof RuntimeException) {
                 throw PreviewExceptionCodes.ERROR.create(e, e.getMessage());
@@ -714,21 +643,18 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
 
     // checked: inputStm is always closed at end of method
     final protected static File createTempFile(@NonNull Data<InputStream> documentData) throws OXException {
-        final InputStream inputStm = documentData.getData();
         File ret = null;
 
-        if ((null != inputStm) && (null != (ret = ClientManager.get().createTempFile("oxpreview")))) {
-            try {
+        try (final InputStream inputStm = documentData.getData()) {
+            if ((null != inputStm) && (null != (ret = ClientManager.get().createTempFile("oxpreview")))) {
                 FileUtils.copyInputStreamToFile(inputStm, ret);
-            } catch (IOException e) {
-                FileUtils.deleteQuietly(ret);
-                ret = null;
-
-                handleExcp(e);
             }
-        }
+        } catch (IOException e) {
+            FileUtils.deleteQuietly(ret);
+            ret = null;
 
-        IOUtils.closeQuietly(inputStm);
+            handleExcp(e);
+        }
 
         return ret;
     }
@@ -892,10 +818,6 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
         final private static long serialVersionUID = 1L;
 
         {
-            put("application/msword", PreviewType.COMPOUND_BINARY);
-            put("application/vnd.ms-powerpoint", PreviewType.COMPOUND_BINARY);
-            put("application/vnd.ms-excel", PreviewType.COMPOUND_BINARY);
-
             put("application/vnd.ms-word.document", PreviewType.OOXML);
             put("application/vnd.ms-word.document.macroenabled.12", PreviewType.OOXML);
             put("application/vnd.ms-word.template", PreviewType.OOXML);
